## Reinhard's ringdown amplitude and phase marginalization

Following the spirit of Reinhard's note, we aim to generalize it to include two ringdown modes. We write down the ringdown signal as

$$
s = F_+h_+ + F_\times h_\times
$$

where

$$
h_+ = A_1 \exp(-t/\tau_1)\cos \left( 2\pi f_1 +\phi_1\right) + A_2 \exp(-t/\tau_2)\cos(2\pi f_2 + \phi_2) \\
h_\times = A_1 \exp(-t/\tau_1)\sin \left( 2\pi f_1 +\phi_1\right) + A_2 \exp(-t/\tau_2)\sin(2\pi f_2 + \phi_2)
$$

Probably $F_+$ and $F_\times$ can be absorbed into $A_{1/2}$ and $\phi_{1/2}$, hence the signal can be parametrized as

$$
s = h_+ + h_\times = A_1 \exp(-t/\tau_1)\cos \left( 2\pi f_1 +\phi_1\right) + A_2 \exp(-t/\tau_2)\cos(2\pi f_2 + \phi_2) \\
+ A_1 \exp(-t/\tau_1)\sin \left( 2\pi f_1 +\phi_1\right) + A_2 \exp(-t/\tau_2)\sin(2\pi f_2 + \phi_2)
$$

As stated by Reinhard, we want to separate the "evolution part" and the "amplitude part" . Define the amplitude part as

$$
A_{c1} = A_1 \cos \phi_1 \\
A_{s1} = A_1 \sin \phi_1 \\
A_{c2} = A_2 \cos \phi_2 \\
A_{s2} = A_2 \sin \phi_2 
$$

and the evolution part as

$$
h_{c1} = \exp(-t/\tau_1) \cos(2\pi f_1) \\
h_{s1} = \exp(-t/\tau_1) \sin(2\pi f_1) \\
h_{c2} = \exp(-t/\tau_2) \cos(2\pi f_2) \\
h_{s2} = \exp(-t/\tau_2) \sin(2\pi f_2)
$$

We write $A=(A_{c1}, A_{s1}, A_{c2}, A_{s2})^T$ and $h = (h_{c1}, h_{s1}, h_{c2}, h_{s2})^T$, then we have $s = h^T A$. The likelihood ratio can be expressed as

$$
\ln \mathcal{L} = -\frac{1}{2}<d-s|d-s> + \frac{1}{2}<d|d> \\
= <d|s> - \frac{1}{2}<s|s>
$$

Decompose $s$ as $h^T A$, we can derive the likelihood ratio as

$$
\ln \mathcal{L} = -\frac{1}{2} A^T M^{-1} A + A^TD
$$

where 

$$
M^{-1} = <h^T|h> = \begin{pmatrix}
<h_{c1}|h_{c1}> & <h_{c1}|h_{s1}> & <h_{c1}|h_{c2}> & <h_{c1}|h_{s2}> \\
<h_{s1}|h_{c1}> & <h_{s1}|h_{s1}> & <h_{s1}|h_{c2}> & <h_{s1}|h_{s2}> \\
<h_{c2}|h_{c1}> & <h_{c2}|h_{s1}> & <h_{c2}|h_{c2}> & <h_{c2}|h_{s2}> \\
<h_{s2}|h_{c1}> & <h_{s2}|h_{s1}> & <h_{s2}|h_{c2}> & <h_{s2}|h_{s2}>
\end{pmatrix}
$$

and

$$
D = \begin{pmatrix}
<d|h_{c1}> \\
<d|h_{s1}> \\
<d|h_{c2}> \\
<d|h_{s2}> 
\end{pmatrix}
$$

Our aim is to marginalize A. Using Gaussian Integral, we get

$$
\int e^{-\frac{1}{2}A^T M^{-1} A + A^TD} \mathrm{dA} = 2\pi \sqrt{|M|}
$$

Therefore, with two ringdown modes, we only need to calculate the matrix $M^{-1}$, which means calculating 16 (probably 10 due to symmetry) inner products, then take the inverse to get $M$ and calculate its determinant.

## 

## Inspiral-merger-ringdown waveform phase marginalization

I describe a procedure to analytically marginalize the phase in gravitational wave ringdown parameter estimation.

First I recap the existing implementation of coalescence phase marginalization in *pycbc_inference*, which can be found [here](https://github.com/yi-fan-wang/pycbc/blob/master/pycbc/inference/models/marginalized_gaussian_noise.py). The logarithm likelihood of likelihood function reads

$$
\log \mathcal{L} = -\frac{1}{2}<d-h|d-h>
$$

where the inner product $<.|.>$    is defined as 

$$
<a|b> = 4\Re\int_{f_{low}}^{f_{high}}\frac{\tilde{d}^{\ast}(f)\tilde{h}(f)}{S_n(f)}df      
$$

Further decompose the logarithm of likelihood as 

$$
\log \mathcal{L} = <d|h> -\frac{1}{2}<h|h> - \frac{1}{2}<d|d>
$$

Note an intriguing fact, that the first term needs only to be computed once for a fixed coalescence phase, and other phase values will only introduce a phase offset. I think this fact inspires people to find an analytical marginalization over the coalescence phase. The gravitational wave waveform $h$  can be written as the following

$$
\tilde{h}(f) = \tilde{h}^{0}(f)e^{i\phi} 
$$

Hence the likelihood can be written as

$$
\mathcal{L}_{marg} = \frac{1}{2\pi}\int_0^{2\pi}
\exp{\left[\Re\left({O(d,h^0})e^{i\phi}\right)\right]}d\phi + ...
$$

where the left hand side the likelihood with the coalescence phase being analytically marginalized over. The $O(d,h^0)$ is a complex inner product. For simplicity I drop all the tilt on top of d and h, but they should be frequency series. The ... are terms independent from phase. Denote the complex inner product as a complex number $x+iy$, then multiplying the phase offset yields

$$
O(d,h^0)e^{i\phi} = (x+iy)(\cos\phi + i \sin\phi)
$$

The real part of it is nothing but $x\cos\phi-y\sin\phi$. A useful property of modified Bessel function of the first kind can help to compute the integral. Consider

$$
I_0(x) = \frac{1}{\pi}\int_0^\pi \exp (x\cos\theta)d\theta
$$

(see [here](http://www.mhtlab.uwaterloo.ca/courses/me755/web_chap4.pdf), page 20). Therefore the above integral of the first term of the marginalized likelihood is  $I_0(\sqrt{x^2+y^2})$, the term in the parentheses is nothing but the modulo of the complex inner produce between data $d$ and the gravitational wave $h^0$ with phase being 0.

## Review of decomposing Ringdown waveform with  spheroidal harmonics

We form a quantity as $h_+ +ih_\times $, it has spin two, so it can be decomposed with respect to spin-2 weighted spherical or spheroidal harmonics. In the following I ignore the overtone index $n$, and simply denote spin-2 spheroidal/spherical harmonics by $Y_{lm}$

$$
h_+ + ih_\times = \sum_l\sum_{m=-l}^{l} Y_{lm}h_{lm} = \sum_l \sum_{m=1}^{l} [Y_{lm}h_{lm} + Y_{l-m}h_{l-m}]
$$

In the context of Ringdown

$$
h_{lm} = A_{lm}e^{-\frac{t}{\tau_{lm}}}e^{i(\omega_{lm}t+\phi_{lm})}
$$

In the non-precessing case, there is a symmetry between the $+m$ and $-m$ modes as

$$
h_{l-m} =(-1)^lh_{lm}^\ast
$$

Therefore

$$
h_+ + ih_\times = \sum_l \sum_{m=1}^l [Y_{lm}h_{lm} + (-1)^l Y_{l-m} h_{lm}^\ast]
$$

From the above expression we can take the real part to yield $h_+$ as 

$$
h_+ = \frac{1}{2} \sum_l\sum_{m=1}^l \{ [Y_{lm}h_{lm} + (-1)^lY_{l-m}h_{lm}^\ast] + \\
 \left[Y_{lm}^\ast h_{lm}^\ast + (-1)^l Y_{l-m}^\ast h_{lm}\right] \}\\
= \frac{1}{2}\sum_l \sum_{m=1}^l \{[Y_{lm} + (-1)^lY_{l-m}^\ast] h_{lm} + \\
\left[Y_{lm}^\ast + (-1)^lY_{l-m}^\ast \right]h_{lm}^\ast\} 
$$

Taking the Fourier transform, and note a property that $\tilde{h}^\ast_{lm} (f) = [\tilde{h}_{lm}(-f)]^\ast $ , we get the plus polarization in Fourier domain

$$
\tilde{h_+}(f) = \frac{1}{2}\sum_l \sum_{m=1}^l \{ [Y_{lm} + (-1)^l Y_{l-m}^\ast]\tilde{h_{lm}}(f) \\
+\left[ Y_{lm}^\ast + (-1)^l Y_{l-m}^\ast\right] [\tilde{h}_{lm}(-f)]^\ast \}
$$

Note that we only consider positive frequency here. I think the reasoning behind is because $h_+$ (in the time domain) is real, hence there is a symmetry $\tilde{h}_+(-f) = [\tilde{h}_+(f)]^\ast$. Thus we only need to take care of the single sided of the waveform in Fourier domain.

Another key assumption/behavior here is that people find  $\tilde{h}_{lm}(-f) = 0 $ when $m>0$. I'm not sure about it for the ringdown case. But let's say it's true, then we have 

$$
\tilde{h}_+(f) = \frac{1}{2} \sum_l \sum_{m=1}^{l} [Y_{lm} + (-1)^l Y_{l-m}^\ast ] \tilde{h}_{lm}(f)
$$

For ringdown waveform, taking the Fourier transform yields

$$
\tilde{h}_{lm}(f) = A_{lm} e^{i\phi_{lm}} \frac{i\tau_{lm}}{2\pi(f_0-f)\tau_{lm} + i}
$$

If we can ignore the negative frequency part, of course we have 

$$
\tilde{h}_+(\phi) = \tilde{h}_+(\phi=0) e^{i\phi}
$$

The same relation is also true for the cross polarization thus we can perform the phase marginalization analytically. 
